==> equation_tree-0.0.28.tar.gz: equation_tree-0.0.28/docs/index.md <==
# Equation Tree

The Equation Tree package is an equation toolbox with symbolic regression in mind. It represents expressions as an incomplete binary [equation tree](user-guide/equation-formats.md) and has various features tailored towards testing symbolic regression algorithms or training models. The most notable features are:

- [**Equation Sampling**](user-guide/equation-sampling.md)
- Calculating [Distance Metrics](user-guide/distance-metrics.md) between equations

It also encompasses a variety of [additional features](user-guide/additional-features.md). For example, to obtain information about existing equation list that can, in turn, be used in our sampling method.

## Relevant Publication

For reference and information about the evaluation of our package, read our NeuroIPS 2023 [paper](https://openreview.net/forum?id=i3PecpoiPG):

Marinescu\*, I., Strittmatter\*, Y, Williams, C, Musslick, S. "Expression Sampler as a Dynamic Benchmark for Symbolic Regression." In *NeurIPS 2023 AI for Science Workshop*. (2023), . [*equal contribution]

## About

This project is in active development by
the <a href="https://musslick.github.io/AER_website/Research.html">Autonomous Empirical Research
Group</a>
(package developer: <a href="https://younesstrittmatter.github.io/">Younes Strittmatter</a>,
PI: <a href="https://smusslick.com/">Sebastian Musslick</a>. This research program is supported by
Schmidt Science Fellows, in partnership with the Rhodes Trust, as well as the Carney BRAINSTORM
program at Brown University.

==> equation_tree-0.0.31.tar.gz: equation_tree-0.0.31/docs/index.md <==
# Equation Tree

The Equation Tree package is an equation toolbox with symbolic regression in mind. It represents expressions as an incomplete binary [equation tree](user-guide/equation-formats.md) and has various features tailored towards testing symbolic regression algorithms or training models. The most notable features are:

- [**Equation Sampling**](user-guide/equation-sampling.md)
- Calculating [Distance Metrics](user-guide/distance-metrics.md) between equations

It also encompasses a variety of [additional features](user-guide/additional-features.md) including the capability to analyse distribution parameters for a given set of equations. For example, to obtain information about a specific field one can use the [equation scraper](https://autoresearch.github.io/equation-scraper/tutorials/equation_scraper_tutorial/) to scrape equations from wikipedia and then use the sampler to generate equations that resemble a equations of a scientific field. 

## Relevant Publication

For reference and information about the evaluation of our package, read our NeuroIPS 2023 [paper](https://openreview.net/forum?id=i3PecpoiPG):

Marinescu\*, I., Strittmatter\*, Y, Williams, C, Musslick, S. "Expression Sampler as a Dynamic Benchmark for Symbolic Regression." In *NeurIPS 2023 AI for Science Workshop*. (2023), . [*equal contribution]

## About

This project is in active development by
the <a href="https://musslick.github.io/AER_website/Research.html">Autonomous Empirical Research
Group</a>
(package developer: Ioana Marinescu and <a href="https://younesstrittmatter.github.io/">Younes Strittmatter</a>,
PI: <a href="https://smusslick.com/">Sebastian Musslick</a>. This research program is supported by
Schmidt Science Fellows, in partnership with the Rhodes Trust, as well as the Carney BRAINSTORM
program at Brown University.
